@@ -2,7 +2,7 @@ __author__ = "Vini Salazar"
 __license__ = "MIT"
 __maintainer__ = "Vini Salazar"
 __url__ = "https://github.com/vinisalazar/bioprov"
-__version__ = "0.1.12"
+__version__ = "0.1.15"
 
 
-from .programs import prodigal, prokka, kaiju, kaiju2table
+from .programs import prodigal, diamond, blastn, prokka, kaiju, kaiju2table
