@@ -2,7 +2,7 @@ __author__ = "Vini Salazar"
 __license__ = "MIT"
 __maintainer__ = "Vini Salazar"
 __url__ = "https://github.com/vinisalazar/bioprov"
-__version__ = "0.1.12"
+__version__ = "0.1.15"
 
 
 """
@@ -10,11 +10,45 @@ Module for holding preset instances of the Program class.
 """
 
 from os import path
+from pathlib import Path
 from bioprov import config, File
 from bioprov.src.main import Parameter, Program, PresetProgram
 from bioprov.utils import assert_tax_rank, Warnings
 
 
+def diamond(blast_type, sample, db, query_tag="query", outformat=6, extra_flags=None):
+    """
+    :param str blast_type: Which aligner to use ('blastp' or 'blastx').
+    :param Sample sample: Instance of BioProv.Sample.
+    :param str db: A string pointing to the reference database path.
+    :param str query_tag: A tag for the query file.
+    :param int outformat: The output format to gather from diamond (0, 5 or 6).
+    :param list extra_flags: A list of extra parameters to pass to diamond
+        (e.g. --sensitive or --log).
+    :return: Instance of PresetProgram containing Diamond.
+    :rtype: BioProv.PresetProgram.
+    """
+
+    _diamond = PresetProgram(
+        name="diamond",
+        params=(
+            Parameter(key=blast_type),
+            Parameter(key="--db", value=db),
+            Parameter(key="--outfmt", value=outformat),
+        ),
+        sample=sample,
+        input_files={"--query": query_tag},
+        output_files={"--out": ("_dmnd_hits", "_dmnd_hits.tsv")},
+    )
+
+    if extra_flags is not None:
+        params = [Parameter(key=command) for command in extra_flags]
+        for param in params:
+            _diamond.add_parameter(param)
+
+    return _diamond
+
+
 def prodigal(sample=None, input_tag="assembly"):
     """
     :param sample: Instance of BioProv.Sample.
@@ -36,11 +70,52 @@ def prodigal(sample=None, input_tag="assembly"):
     return _prodigal
 
 
+def _create_blast_preset(blast_type, sample, db, query_tag, outformat):
+    """
+    :param str blast_type: What BLAST program to build (e.g. 'blastn');
+    :return: Instance of PresetProgram for the chosen blast program type.
+    :rtype: BioProv.PresetProgram.
+    """
+
+    if db is not None:
+        db_dir = Path(db).parent.is_dir()
+        assert db_dir, "Path to the reference database does not exist"
+
+    _blast_program = PresetProgram(
+        name=blast_type,
+        params=(
+            Parameter(key="-db", value=db),
+            Parameter(key="-outfmt", value=outformat),
+        ),
+        sample=sample,
+        input_files={"-query": query_tag},
+        output_files={"-out": (f"{blast_type}_hits", f"_{blast_type}_hits.txt")},
+    )
+
+    return _blast_program
+
+
+def blastn(sample=None, db=None, query_tag="query", outformat=6):
+    """
+    :param Sample sample: Instance of BioProv.Sample.
+    :param str db: A string pointing to the reference database directory and title.
+    :param str query_tag: A tag for the query file.
+    :param int outformat: The output format to gather from blastn.
+    :return: Instance of PresetProgram for BLASTN.
+    :rtype: BioProv.PresetProgram.
+    :raises AssertionError: Path to the reference database does not exist.
+    """
+
+    _blastn = _create_blast_preset("blastn", sample, db, query_tag, outformat)
+
+    return _blastn
+
+
 def prokka_():
     """
     :return: Instance of PresetProgram containing Prokka.
     """
-    _prokka = PresetProgram(program=Program("prokka"))
+    _prokka = PresetProgram(name=Program("prokka"))  # no cover
 
 
 def prokka(
@@ -103,10 +178,12 @@ def prokka(
         _prokka.add_parameter(param, _print=False)
 
     if path.isdir(output_path):
-        print(f"Warning: {output_path} directory exists. Will overwrite.")
-        _prokka.add_parameter(Parameter(key="--force", value="", kind="misc"))
+        print(f"Warning: {output_path} directory exists. Will overwrite.")  # no cover
+        _prokka.add_parameter(
+            Parameter(key="--force", value="", kind="misc")
+        )  # no cover
 
-    # Add files according to their extension # To-do: add support for SeqFile
+    # Add files according to their extension # TODO: add support for SeqFile
     extensions_parser = {
         ".faa": lambda file: _sample.add_files(File(file, tag=proteins)),
         ".fna": lambda file: _sample.add_files(File(file, tag=contigs)),
@@ -125,7 +202,7 @@ def prokka(
         _ = func(file_)  # Add file based on extension
 
     if add_param_str:  # Any additional parameters are added here.
-        _prokka.cmd += f" {add_param_str}"
+        _prokka.cmd += f" {add_param_str}"  # no cover
 
     # Input goes here, must be last positionally.
     _prokka.add_parameter(
@@ -166,7 +243,7 @@ def kaiju(
             kaiju_out_name,
         )
     else:
-        output_path = path.join(output_path, kaiju_out_name)
+        output_path = path.join(output_path, kaiju_out_name)  # no cover
     _sample.add_files(File(output_path, tag="kaiju_output"))
 
     kaiju_ = Program("kaiju")
@@ -183,7 +260,7 @@ def kaiju(
         kaiju_.add_parameter(p, _print=False)
 
     if add_param_str:
-        kaiju_.cmd += f" {add_param_str}"
+        kaiju_.cmd += f" {add_param_str}"  # no cover
 
     return kaiju_
 
@@ -236,6 +313,6 @@ def kaiju2table(
     kaiju2table_.cmd += f" {str(_sample.files[kaiju_output])}"
 
     if add_param_str:
-        kaiju2table_.cmd += f" {add_param_str}"
+        kaiju2table_.cmd += f" {add_param_str}"  # no cover
 
     return kaiju2table_
