@@ -2,7 +2,7 @@ __author__ = "Vini Salazar"
 __license__ = "MIT"
 __maintainer__ = "Vini Salazar"
 __url__ = "https://github.com/vinisalazar/bioprov"
-__version__ = "0.1.12"
+__version__ = "0.1.15"
 
 """
 Module containing base provenance attributes.
@@ -10,9 +10,10 @@ Module containing base provenance attributes.
 This module extracts system-level information, such as user and environment
 settings, and stores them. It is invoked to export provenance objects. 
 """
-from bioprov import Project
+from bioprov import Project, Parameter
 from bioprov.utils import Warnings, build_prov_attributes, serializer_filter
 from prov.model import ProvDocument
+from prov.dot import prov_to_dot
 
 
 class BioProvDocument:
@@ -39,6 +40,8 @@ class BioProvDocument:
         )
         self.ProvDocument = ProvDocument()
         self.project = project
+        self.project.document = self.ProvDocument
+        self._dot = prov_to_dot(self.ProvDocument)
         self._entities = dict()
         self._activities = dict()
         self._agents = dict()
@@ -56,10 +59,18 @@ class BioProvDocument:
         if _iter_samples:
             self._iter_samples()
 
-    # def __repr__(self):
-    #     return "BioProvDocument describing Project '{}' with {} samples.".format(
-    #         self.project.tag, len(self.project)
-    #     )
+    def __repr__(self):
+        return "BioProvDocument describing Project '{}' with {} samples.".format(
+            self.project.tag, len(self.project)
+        )
+
+    @property
+    def dot(self):
+        return prov_to_dot(self.ProvDocument)
+
+    @dot.setter
+    def dot(self, value):
+        self._dot = value
 
     def _add_project_namespaces(self):
         """
@@ -99,15 +110,6 @@ class BioProvDocument:
         else:
             self.project.entity = self.ProvDocument.entity(f"project:{self.project}")
 
-        # I may implement this check later. Related to #10
-        # # Check if project_csv exists
-        # if "project_csv" in self.project.files.keys():
-        #     self.project_file_entity = self.ProvDocument.entity(
-        #         "project:{}".format(self.project.files["project_csv"])
-        #     )
-        # else:
-        #     pass
-
     def _add_env_and_user_namespace(self):
         self.ProvDocument.add_namespace(
             "users", f"Users associated with BioProv Project '{self.project.tag}'"
@@ -135,16 +137,16 @@ class BioProvDocument:
             self._agents[_user] = _user_bundle.agent(_user_preffix)
             for _env_hash, _env in _env_dict.items():
                 if self.add_attributes:
-                    self._entities[_env_hash] = _user_bundle.entity(
+                    self._agents[_env_hash] = _user_bundle.agent(
                         f"envs:{_env}",
                         other_attributes=build_prov_attributes(
                             _env.env_dict, _env.env_namespace
                         ),
                     )
                 else:
-                    self._entities[_env_hash] = _user_bundle.entity(f"envs:{_env}")
-                _user_bundle.wasAttributedTo(
-                    self._entities[_env_hash], self._agents[_user]
+                    self._agents[_env_hash] = _user_bundle.agent(f"envs:{_env}")
+                _user_bundle.actedOnBehalfOf(
+                    self._agents[_env_hash], self._agents[_user]
                 )
 
     def _iter_samples(self):
@@ -164,7 +166,7 @@ class BioProvDocument:
         sample.ProvBundle = self.ProvDocument.bundle(sample.namespace_preffix)
         sample.ProvBundle.set_default_namespace(sample.name)
         self._entities[sample.name] = sample.ProvBundle.entity(f"samples:{sample.name}")
-        self.ProvDocument.wasDerivedFrom(
+        sample.ProvBundle.wasDerivedFrom(
             self._entities[sample.name], self.project.entity
         )
 
@@ -176,8 +178,8 @@ class BioProvDocument:
         :return: updates the sample.ProvBundle by creating PROV objects for the files.
 
         """
-        sample.files_namespace_preffix = f"{sample.name}.files"
-        sample.ProvBundle.add_namespace(
+        sample.files_namespace_preffix = "files"
+        sample.file_namespace = sample.ProvBundle.add_namespace(
             sample.files_namespace_preffix,
             f"Files associated with Sample {sample.name}",
         )
@@ -185,14 +187,14 @@ class BioProvDocument:
         # Files PROV attributes: namespace, entities
         for key, file in sample.files.items():
             # Create Namespace
-            file.namespace = sample.ProvBundle.add_namespace(file.name, str(file.path))
+            # file.namespace = sample.ProvBundle.add_namespace(file.name, str(file.path))
 
             # Same function call, but in the first we pass the 'other_attributes' argument
             if self.add_attributes:
                 self._entities[file.name] = sample.ProvBundle.entity(
                     f"{sample.files_namespace_preffix}:{file.name}",
                     other_attributes=build_prov_attributes(
-                        file.serializer(), file.namespace
+                        file.serializer(), sample.file_namespace
                     ),
                 )
             else:
@@ -208,7 +210,7 @@ class BioProvDocument:
 
     def _create_program_entities(self, sample):
         # Programs PROV attributes: namespace, entities
-        programs_namespace_prefix = f"{sample.name}.programs"
+        programs_namespace_prefix = f"programs"
         programs_namespace = sample.ProvBundle.add_namespace(
             programs_namespace_prefix,
             f"Programs associated with Sample {sample.name}",
@@ -242,8 +244,8 @@ class BioProvDocument:
                     endTime=last_run.end_time,
                 )
 
-            self.ProvDocument.wasDerivedFrom(
-                self._activities[program.name], self._entities[last_run.env]
+            sample.ProvBundle.wasAssociatedWith(
+                self._activities[program.name], self._agents[last_run.env]
             )
 
             inputs, outputs = self._get_IO_from_params(program)
@@ -251,7 +253,7 @@ class BioProvDocument:
             self._add_IO_relationships(sample, program, outputs, "output")
 
     def _add_IO_relationships(self, sample, program, io_list, io_type):
-        # To-do: replace Sample for Project when implementing Project.files and programs
+        # TODO: replace Sample for Project when implementing Project.files and programs
 
         """
         Add PROV relationships between Program and input/output files.
@@ -297,10 +299,21 @@ class BioProvDocument:
         inputs, outputs = [], []
 
         for _, parameter in program.params.items():
-            if parameter["kind"] == "input":
-                inputs.append(parameter["value"])
-            elif parameter["kind"] == "output":
-                outputs.append(parameter["value"])
+            assert isinstance(parameter, Parameter), (
+                Warnings()["incorrect_type"](parameter, Parameter)
+                + "\nPlease check if Programs were correctly deserialized."
+            )
+            if parameter.kind == "input":
+                # This loop is because some positional arguments may have empty values (value stored in parameter.key)
+                if parameter.value:
+                    inputs.append(parameter.value)
+                else:
+                    inputs.append(parameter.key)
+            elif parameter.kind == "output":
+                if parameter.value:
+                    outputs.append(parameter.value)
+                else:
+                    outputs.append(parameter.key)
 
         return inputs, outputs
 
