@@ -2,7 +2,7 @@ __author__ = "Vini Salazar"
 __license__ = "MIT"
 __maintainer__ = "Vini Salazar"
 __url__ = "https://github.com/vinisalazar/bioprov"
-__version__ = "0.1.12"
+__version__ = "0.1.15"
 
 
 """
@@ -17,7 +17,7 @@ Testing for the bioprov.src.main module.
  Also tests JSON and tab-delimited serializer methods.
 """
 
-# To-do: organize this
+# TODO: organize this
 import datetime
 import pandas as pd
 from bioprov.src.main import (
@@ -26,6 +26,8 @@ from bioprov.src.main import (
     parse_params,
     Program,
     Run,
+    dict_to_sample,
+    json_to_dict,
 )
 from coolname import generate_slug
 from os import remove
@@ -37,8 +39,9 @@ from bioprov import (
     write_json,
     from_json,
     BioProvDocument,
+    BioProvDB,
 )
-from bioprov.src.main import dict_to_sample, json_to_dict
+from bioprov.utils import dict_to_sha1
 from bioprov.data import synechococcus_genome, picocyano_dataset
 from bioprov.programs import prodigal
 
@@ -237,7 +240,7 @@ def test_json_Sample():
     remove(str(sample.files["json"]))
 
 
-def test_project_json_and_prov(debug=False):
+def test_project_json_and_prov():
     def import_project():
         _project = read_csv(
             picocyano_dataset,
@@ -249,9 +252,9 @@ def test_project_json_and_prov(debug=False):
         return _project
 
     def add_and_run_programs(_project):
-        for k, sample in _project.items():
-            sample.add_programs(prodigal(sample=sample))
-            sample.run_programs()
+        for k, _sample in _project.items():
+            _sample.add_programs(prodigal(sample=_sample))
+            _sample.run_programs()
 
     def export_json(path, _project):
         return _project.to_json(path)
@@ -279,10 +282,39 @@ def test_project_json_and_prov(debug=False):
     prov_json_out = "./gentax_picocyano_prov.json"
     export_prov_json(prov_json_out, prov)
 
-    # Clean up
+    # Clean up - JSON
     for f in (json_out, json_out_2, prov_json_out):
         remove(f)
 
-    # Useful for debugging
-    if debug:
-        return project, prov
+    # Clean up - prodigal output
+    for _, sample in project.items():
+        for key, file in sample.files.items():
+            if key != "assembly":  # we are keeping those
+                remove(file.path)
+
+    # Test DB, project.__delitem__, project.sha1
+    project.db = BioProvDB(json_out_2)  # Let's not waste this variable
+    project.update_db()
+
+    # Maybe put this function in config
+    def get_db_hash():
+        result, query = project.query_db()
+        _db_hash = dict_to_sha1(result)
+        return _db_hash
+
+    old_db_sha1 = get_db_hash()
+
+    project.auto_update = True
+    old_project_sha1 = project.sha1
+    del project["GCF_000010065.1_ASM1006v1"]
+    new_project_sha1 = project.sha1
+    new_db_sha1 = get_db_hash()
+    assert (
+        new_project_sha1 != old_project_sha1
+    ), "Project hashes aren't different, but Project has changed!"
+    assert (
+        old_db_sha1 != new_db_sha1
+    ), "Database hashes aren't different, but Project.auto_update() is on and Project has changed!"
+
+    # Clean up again
+    remove(json_out_2)
